from ekispert.models.operational_state import OperationalState
from ekispert.models.point import Point
from ..base import Base

class Stop(Base):
  def __init__(self, data = None):
    super().__init__()
    if data is None:
      return
    self.sets(data)

  def sets(self, data: dict):
    for key in data:
      self.set(key, data[key])

  def set(self, key: str, value: any):
    match key.lower():
      case "arrivalstate":
        self.arrival_state = OperationalState(value)
      case "departurestate":
        self.departure_state = OperationalState(value)
      case "point":
        self.point = Point(value)
      case _:
        raise ValueError(f"key: {key} is not defined in Stop")



from ekispert.models.formation import Formation
from ..base import Base

class Change(Base):
  def __init__(self, data = None):
    super().__init__()
    if data is None:
      return
    self.sets(data)

  def sets(self, data: dict):
    for key in data:
      self.set(key, data[key])

  def set(self, key: str, value: any):
    match key.lower():
      case "nextlinedirection":
        self.next_line_direction = value
      case "openside":
        self.open_side = value
      case "formation":
        self.formation = Formation(value)
      case _:
        raise ValueError(f"key: {key} is not defined in Change")




from ..base import Base

from collections import namedtuple

Type = namedtuple('Type', 'text detail')

class Station(Base):
  def __init__(self, data = None):
    super().__init__()
    if data is None:
      return
    self.sets(data)

  def sets(self, data):
    for key in data:
      self.set(key, data[key])

  def set(self, key: str, value: any):
    match key.lower():
      case "code":
        self.code = int(value)
      case "name":
        self.name = value
      case "oldname":
        self.old_name = value
      case "yomi":
        self.yomi = value
      case "type":
        # value is string or not
        if isinstance(value, str):
          self.type = Type(
            text = value,
            detail = None)
        else:
          self.type = Type(
            text = value["text"],
            detail = value["detail"])
      case _:
        raise ValueError(f"key: {key} is not defined in Station")